@@ -18,6 +18,7 @@ class RspecTest(CliTestCase):
                           'rspec', str(self.test_files_dir.joinpath("rspec.xml")))
 
         self.assertEqual(result.exit_code, 0)
-        payload = json.loads(gzip.decompress(responses.calls[1].request.body).decode())
+        payload = json.loads(gzip.decompress(
+            responses.calls[1].request.body).decode())
         expected = self.load_json_from_file(self.result_file_path)
         self.assert_json_orderless_equal(expected, payload)
